""" Module tests
"""
import sys
from openmlhub import model_logger
from openmlhub.config import OpenMLHubConf

def test_openmlhub_imported():
    assert "openmlhub" in sys.modules

def test_openmlhub_logger():
    conf = OpenMLHubConf("","")
    model_logger(conf)


import requests

from .config import OpenMLHubConf

class OpenMLHubClientError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)
    
class OpenMLHubClient:
    """ This client implements the communication with OpenMLHub
    """
    def __init__(self, conf: OpenMLHubConf) -> None:
        self.conf = conf

            
    def log(self):
        """ Implement data logging
        """
        resp = requests.post('https://openmlhub.com/log_model',
            headers= {
                'uid': self.conf.uid,
                'api_key': self.conf.api_key
            },
            json={})

        if resp.status_code != 201:
            raise OpenMLHubClientError(f"log model, invalid response: {resp.status_code}")


""" Logger implements logging funcionality for machine learning models.
"""

from .client import OpenMLHubClient

class Logger(object):
    """ This class collects infomration from the model and datasources, and 
        allow publish the data to OpenMLHub
    """
    def __init__(self, client: OpenMLHubClient, version: str = "draft") -> None:
        self._client = client
        self.version = version
        

    def log(self):
        self._client.log()
        




from .config import OpenMLHubConf
from .client import OpenMLHubClient
from .logger import Logger


def model_logger(conf: OpenMLHubConf):
    """ Create a specific model logger to share trainning and model infomration
        with OpenMLHub
    """
    client = OpenMLHubClient(conf)
    return Logger(client)